@@ -243,7 +243,6 @@ void MainWindow::onLoadFinished(bool isSuccess) {
     // ready!
     qDebug() << "loaded html page";
     ui->webView->disconnect(this, SLOT(onLoadFinished(bool)));
-    createMenu();
 
     m_isReady = true; // ready to start javascript
 
@@ -281,6 +280,8 @@ void MainWindow::onLoadFinished(bool isSuccess) {
         "directionsDisplay.setMap(map);";
 
     runJavascript(script);
+
+    createMenu();
 }
 
 void MainWindow::createMenu() {
@@ -298,7 +299,6 @@ void MainWindow::createMenu() {
     pAction = new QAction("Terrain", m_pViewActionGroup); pAction->setCheckable(true); pAction->setChecked(viewMode==3);
     menuBar()->addActions(m_pViewActionGroup->actions());
     connect(m_pViewActionGroup, SIGNAL(triggered(QAction*)), this, SLOT(onViewChanged(QAction*)));
-    setView(viewMode);
 
     // menuBar()->addAction("Reload", this, SLOT(reload()));
     // menuBar()->addAction("Find Address", this, SLOT(find()));
@@ -320,18 +320,17 @@ void MainWindow::createMenu() {
     m_pTrafficLayer = menuBar()->addAction("Traffic Layer", this, SLOT(onTrafficLayer()));
     m_pTrafficLayer->setCheckable(true);
     m_pTrafficLayer->setChecked(traffic);
+    onTrafficLayer();
 
     m_pCyclingLayer = menuBar()->addAction("Bicycling Layer", this, SLOT(onBicyclingLayer()));
     m_pCyclingLayer->setCheckable(true);
     m_pCyclingLayer->setChecked(bicycle);
+    onBicyclingLayer();
 
     m_pAccuracyAction = menuBar()->addAction("Show Accuracy", this, SLOT(onShowAccuracy()));
     m_pAccuracyAction->setCheckable(true);
     m_pAccuracyAction->setChecked(false);
-
-    if ( traffic ) onTrafficLayer();
-    if ( bicycle ) onBicyclingLayer();
-
+    onShowAccuracy();
 
 #ifdef Q_WS_MAEMO_5
     addFullscreenToMenu();
